A scrollable list of image cards with less boilerplate code. Quick, static and reusable.

By using [ImageCardList](https://pub.dev/documentation/image_card_list/latest/image_card_list/ImageCardList-class.html) instead of manually creating such list, you get:

- A scrollable list of pictures in a single step.
- More readable and reusable code structure.
- A largely reduced boilerplate.
- Easy integration.
- Flexibility over changing a lot of properties.

<img src="images/main.gif" height="220" width="340">

# Mechanism

A [SingleChildScrollView](https://api.flutter.dev/flutter/widgets/SingleChildScrollView-class.html) wrapped around [Row](https://api.flutter.dev/flutter/widgets/Row-class.html)/[Column](https://api.flutter.dev/flutter/widgets/Column-class.html) widget with a list of [Card](https://api.flutter.dev/flutter/material/Card-class.html)s containing [AssetImage](https://api.flutter.dev/flutter/painting/AssetImage-class.html) and a [Text](https://api.flutter.dev/flutter/dart-html/Text-class.html) widget.

### Check 

[image_card_list](https://pub.dev/documentation/image_card_list/latest/image_card_list/ImageCardList-class.html) documentation.

# Usage

- Add dependency

```yaml
dependencies:
  ...
  image_card_list: //[version]
```

- Use assets/network images all together. 

```dart
class HomePage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: ImageCardList(
            map: {
              "Tiger": "assets/tiger.jpg",
              "Wolf": "https://i.ibb.co/Gp8xvsx/images-15.jpg",
              "Leopard": "assets/leopard.jpeg",
              "Zebra": "assets/zebra.jpg",
              "Giraffe": "assets/giraffe.jpeg",
              "Bear": "assets/bear.jpeg",
              "Monkey": "assets/monkey.jpeg"
            },
            displayNameTag: true,
          ),
    );
  }
}
```
Therefore, the widget is smart enough to know whether an image is being used from assets or http. The 'displayNameTag' property is mandatory so as to show/hide the nameTag and to provide unique identification to each image in use.

# Breakdown

- Adding an image from asset.

```dart
ImageCardList(
            map: {
              "Tiger": "assets/tiger.jpg",
            },
            displayNameTag: true,
          );
```

- Adding an image from network.

```dart
ImageCardList(
            map: {
              "Wolf": "https://i.ibb.co/Gp8xvsx/images-15.jpg",
            },
            displayNameTag: true,
          );
```

### NOTE:

With initial release it wont be easy or possible to have full control over the cards, especially when working with animations and displaying explicit information on Tap events. However, future changes will bring significant improvements.

